--================================
-- scriptController_part3.ms
--
-- by: Autodesk Scripting and SDK Learning Channel
-- [ youtube.com/user/scriptingsdkhowtos]
-- [ scriptingandsdkhowto@autodesk.com | scriptingandsdkhowto@gmail.com ]
--
-- The following script operates on the user's current selection. The first
-- object selected is assigned a script controller on its z-position track to 
-- keep it above the other objects in the selection. This script can be used 
-- to stack extruded splines, boxes, cylinders, cones, and tubes.
--
--================================

function keepAbove topObj bottomTrackArray = (
	
	fs = float_script()
	topObj.position.controller.z_position.controller = fs
	
	tmpScript = "amax #("
	
	for i = 1 to bottomTrackArray.count do (
		
		track = bottomTrackArray[i]
		
		variableName = "var_" + (i as string)
		
		fs.addTarget variableName track
		
		tmpScript += variableName
		
		if i < bottomTrackArray.count then (
			
			tmpScript += ", "
			
		)
		
	)
	
	tmpScript += " )"
	
	fs.script = tmpScript
	
)

function getNestedSubanim obj subanimNameArray = (
	
	tmpSubanim = obj
	
	for subanimName in subanimNameArray while tmpSubanim != undefined do (
		
		tmpSubanim = tmpSubanim[ subanimName ]
		
	)
	
	tmpSubanim
	
)

global validTrackPaths = #( \
	--#( #Object__Box, #height ), \
	#( 4, #height ), \
	#( #Modified_Object, #Extrude, #amount ) \
)

function keepFirstAboveSelection = (
	
	currentSelection = getCurrentSelection()
	
	if currentSelection.count >= 2 then (
		
		topObject = currentSelection[1]
		
		bottomObjects = for i = 2 to currentSelection.count collect currentSelection[i]
		
		heightTracks = (
			
			for obj in bottomObjects collect (
				
				track = undefined
				
				for trackPath in validTrackPaths while track == undefined do (
					
					track = getNestedSubanim obj trackPath
					
				)
				
				if track != undefined then (
					
					track
					
				) else (
					
					dontCollect
					
				)
				
			)
			
		)
		
		if heightTracks.count > 0 then (
			
			keepAbove topObject heightTracks
			
			topObject.parent = bottomObjects[1]
			
			in coordsys parent topObject.pos = [0, 0, 0]
			
		)
		
	) else (
		
		messagebox "Please select two or more objects."
		
	)
	
)

keepFirstAboveSelection()

/*
-- purple box
b1 = box height:10 length:10 width:10 pos:[0, -5, 0]
b1.wirecolor = color 145 28 177
	
-- yellow box
b2 = box height:10 length:10 width:10 pos:[0, 5, 0]
b2.wirecolor = color 225 198 87
	
-- green box
b3 = box height:10 length:10 width:10 pos:[0,0,10]
b3.wirecolor = color 6 135 6

--keepAbove b3 #( b1[#Object__Box][#height], b2[#Object__Box][#height] )

-- keepAbove b3 #( \
-- 	getNestedSubanim b1 #( #Object__Box, #height ), \
-- 	getNestedSubanim b2 #( #Object__Box, #height ) )

bottomBoxes = #( b1, b2 )

heightTracks = for obj in bottomBoxes collect ( \
	
	getNestedSubanim obj #( #Object__Box, #height ) \
	
)

keepAbove b3 heightTracks
*/
















